@@ -1,7 +1,7 @@
 package App::fatten;
 
-our $DATE = '2015-06-17'; # DATE
-our $VERSION = '0.39'; # VERSION
+our $DATE = '2015-07-01'; # DATE
+our $VERSION = '0.40'; # VERSION
 
 use 5.010001;
 use strict;
@@ -852,11 +852,6 @@ sub _add_stripper_args_to_meta {
         schema => ['bool'],
         default => 0,
         tags => ['category:stripping'],
-        description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
     };
 
     $meta->{args}{stripper_ws} = {
@@ -865,11 +860,6 @@ _
         schema => ['bool'],
         default => 1,
         tags => ['category:stripping'],
-        description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
     };
 
     $meta->{args}{stripper_comment} = {
@@ -877,11 +867,6 @@ _
         'summary.alt.bool.not' => "Set strip_comment=0 (don't strip comments) in Perl::Stripper",
         schema => ['bool'],
         default => 1,
-        description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
         tags => ['category:stripping'],
     };
 
@@ -891,11 +876,6 @@ _
         schema => ['bool'],
         default => 1,
         tags => ['category:stripping'],
-        description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
     };
 
     $meta->{args}{stripper_log} = {
@@ -904,11 +884,6 @@ _
         schema => ['bool'],
         default => 0,
         tags => ['category:stripping'],
-        description => <<'_',
-
-Only relevant when stripping using Perl::Stripper.
-
-_
     };
 
     # XXX strip_log_levels
@@ -958,7 +933,7 @@ App::fatten - Pack your dependencies onto your script file
 
 =head1 VERSION
 
-This document describes version 0.39 of App::fatten (from Perl distribution App-fatten), released on 2015-06-17.
+This document describes version 0.40 of App::fatten (from Perl distribution App-fatten), released on 2015-07-01.
 
 =head1 SYNOPSIS
 
@@ -1141,32 +1116,22 @@ Whether to strip included modules using Perl::Stripper.
 
 Set strip_comment=1 (strip comments) in Perl::Stripper.
 
-Only relevant when stripping using Perl::Stripper.
-
 =item * B<stripper_log> => I<bool> (default: 0)
 
 Set strip_log=1 (strip log statements) in Perl::Stripper.
 
-Only relevant when stripping using Perl::Stripper.
-
 =item * B<stripper_maintain_linum> => I<bool> (default: 0)
 
 Set maintain_linum=1 in Perl::Stripper.
 
-Only relevant when stripping using Perl::Stripper.
-
 =item * B<stripper_pod> => I<bool> (default: 1)
 
 Set strip_pod=1 (strip POD) in Perl::Stripper.
 
-Only relevant when stripping using Perl::Stripper.
-
 =item * B<stripper_ws> => I<bool> (default: 1)
 
 Set strip_ws=1 (strip whitespace) in Perl::Stripper.
 
-Only relevant when stripping using Perl::Stripper.
-
 =item * B<test> => I<bool>
 
 Test the resulting output.
